@@ -109,6 +109,7 @@ typedef struct
   GtkWidget *video_vbox;
 
   GtkWidget *effect_frame;
+  GtkWidget *effect_alignment;
   GtkWidget *effect_chooser;
   GtkWidget *throbber_frame;
   GtkWidget *throbber;
@@ -283,12 +284,8 @@ cheese_window_fullscreen_set_timeout (CheeseWindow *cheese_window)
   GSource *source;
 
   cheese_window_fullscreen_clear_timeout (cheese_window);
-
-  /* make a difference between effects page and video preview */
-  if (gtk_notebook_get_current_page (GTK_NOTEBOOK (cheese_window->notebook)) == 0)
-    source = g_timeout_source_new (FULLSCREEN_TIMEOUT);
-  else
-    source = g_timeout_source_new (FULLSCREEN_EFFECTS_TIMEOUT);
+  
+  source = g_timeout_source_new (FULLSCREEN_TIMEOUT);
 
   g_source_set_callback (source, cheese_window_fullscreen_timeout_cb, cheese_window, NULL);
   g_source_attach (source, NULL);
@@ -321,8 +318,10 @@ cheese_window_fullscreen_motion_notify_cb (GtkWidget      *widget,
     {
       cheese_window_fullscreen_show_bar (cheese_window);
     }
-
-    cheese_window_fullscreen_set_timeout (cheese_window);
+    
+    //don't set the timeout in effect-chooser mode
+    if (gtk_notebook_get_current_page (GTK_NOTEBOOK (cheese_window->notebook)) != 1)
+      cheese_window_fullscreen_set_timeout (cheese_window);
   }
   return FALSE;
 }
@@ -354,6 +353,14 @@ cheese_window_toggle_fullscreen (GtkWidget *widget, CheeseWindow *cheese_window)
                       cheese_window);
 
     gtk_window_fullscreen (GTK_WINDOW (cheese_window->window));
+    
+    gtk_widget_set_size_request (cheese_window->effect_alignment, -1, FULLSCREEN_POPUP_HEIGHT);
+    cheese_window_fullscreen_show_bar (cheese_window);
+    
+    //don't set the timeout in effect-chooser mode
+    if (gtk_notebook_get_current_page (GTK_NOTEBOOK (cheese_window->notebook)) != 1)
+      cheese_window_fullscreen_set_timeout (cheese_window);
+
     cheese_window->isFullscreen = TRUE;
   }
   else
@@ -361,13 +368,14 @@ cheese_window_toggle_fullscreen (GtkWidget *widget, CheeseWindow *cheese_window)
     gtk_widget_show_all (cheese_window->window);
     gtk_widget_hide_all (cheese_window->fullscreen_popup);
     gtk_widget_modify_bg (cheese_window->window, GTK_STATE_NORMAL, NULL);
-
+    
     g_signal_handlers_disconnect_by_func (cheese_window->window,
                                           (gpointer) cheese_window_fullscreen_motion_notify_cb, cheese_window);
     g_signal_handlers_disconnect_by_func (cheese_window->screen,
                                           (gpointer) cheese_window_fullscreen_motion_notify_cb, cheese_window);
 
     gtk_window_unfullscreen (GTK_WINDOW (cheese_window->window));
+    gtk_widget_set_size_request (cheese_window->effect_alignment, -1, -1);
     cheese_window->isFullscreen = FALSE;
 
     cheese_window_fullscreen_clear_timeout (cheese_window);
@@ -566,7 +574,9 @@ cheese_window_cmd_delete_file (CheeseWindow *cheese_window, GList *files, gboole
   {
     if (list_length > 1)
     {
-      primary = g_strdup_printf (_("Are you sure you want to permanently delete the %'d selected items?"),
+      primary = g_strdup_printf (ngettext ("Are you sure you want to permanently delete the %'d selected item?",
+                                           "Are you sure you want to permanently delete the %'d selected items?",
+                                           list_length),
                                  list_length);
     }
     else
@@ -654,6 +664,7 @@ cheese_window_cmd_move_file_to_trash (CheeseWindow *cheese_window, GList *files)
           /* forward the list to cmd_delete */
           cheese_window_cmd_delete_file (cheese_window, l, TRUE);
           return;
+
         case GTK_RESPONSE_ACCEPT:
 
           /* create a single file list for cmd_delete */
@@ -661,10 +672,12 @@ cheese_window_cmd_move_file_to_trash (CheeseWindow *cheese_window, GList *files)
           cheese_window_cmd_delete_file (cheese_window, d, TRUE);
           g_list_free (d);
           break;
+
         case CHEESE_RESPONSE_SKIP:
 
           /* do nothing, skip to the next item */
           break;
+
         case CHEESE_RESPONSE_SKIP_ALL:
         case GTK_RESPONSE_CANCEL:
         case GTK_RESPONSE_DELETE_EVENT:
@@ -1211,7 +1224,6 @@ cheese_window_stop_recording (CheeseWindow *cheese_window)
 {
   if (cheese_window->recording)
   {
-    cheese_webcam_stop_video_recording (cheese_window->webcam);
     gtk_action_group_set_sensitive (cheese_window->actions_effects, TRUE);
     gtk_action_group_set_sensitive (cheese_window->actions_toggle, TRUE);
     gtk_widget_set_sensitive (cheese_window->take_picture, FALSE);
@@ -1225,6 +1237,7 @@ cheese_window_stop_recording (CheeseWindow *cheese_window)
     gtk_image_set_from_stock (GTK_IMAGE (cheese_window->image_take_photo_fullscreen),
                               GTK_STOCK_MEDIA_RECORD, GTK_ICON_SIZE_BUTTON);
 
+    cheese_webcam_stop_video_recording (cheese_window->webcam);
     cheese_window->recording = FALSE;
   }
 }
@@ -1282,7 +1295,9 @@ cheese_window_action_button_clicked_cb (GtkWidget *widget, CheeseWindow *cheese_
         gtk_notebook_set_current_page (GTK_NOTEBOOK (cheese_window->fullscreen_bar), 1);
 
         /* show bar, start timeout
-         * ATTENTION: if the countdown is longer than FULLSCREEN_TIMEOUT, the bar will disapear before the countdown ends */
+         * ATTENTION: if the countdown is longer than FULLSCREEN_TIMEOUT,
+         * the bar will disapear before the countdown ends
+         */
         cheese_window_fullscreen_show_bar (cheese_window);
         cheese_window_fullscreen_set_timeout (cheese_window);
       }
@@ -1342,18 +1357,18 @@ cheese_window_preferences_cb (GtkAction *action, CheeseWindow *cheese_window)
 }
 
 static const GtkActionEntry action_entries_main[] = {
-  {"Cheese",       NULL,                   N_("_Cheese")                                  },
+  {"Cheese",       NULL,            N_("_Cheese")                       },
 
-  {"Edit",         NULL,                   N_("_Edit")                                    },
-  {"RemoveAll",    NULL,                   N_("Move All to Trash"), NULL, NULL,
+  {"Edit",         NULL,            N_("_Edit")                         },
+  {"RemoveAll",    NULL,            N_("Move All to Trash"), NULL, NULL,
    G_CALLBACK (cheese_window_move_all_media_to_trash)},
 
-  {"Help",         NULL,                   N_("_Help")                                    },
+  {"Help",         NULL,            N_("_Help")                         },
 
-  {"Quit",         GTK_STOCK_QUIT,         NULL, NULL, NULL, G_CALLBACK (cheese_window_cmd_close)},
-  {"HelpContents", GTK_STOCK_HELP,         N_("_Contents"), "F1", N_("Help on this Application"),
+  {"Quit",         GTK_STOCK_QUIT,  NULL, NULL, NULL, G_CALLBACK (cheese_window_cmd_close)},
+  {"HelpContents", GTK_STOCK_HELP,  N_("_Contents"), "F1", N_("Help on this Application"),
    G_CALLBACK (cheese_window_cmd_help_contents)},
-  {"About",        GTK_STOCK_ABOUT,        NULL, NULL, NULL, G_CALLBACK (cheese_window_cmd_about)},
+  {"About",        GTK_STOCK_ABOUT, NULL, NULL, NULL, G_CALLBACK (cheese_window_cmd_about)},
 };
 
 static const GtkToggleActionEntry action_entries_countdown[] = {
@@ -1378,13 +1393,13 @@ static const GtkRadioActionEntry action_entries_toggle[] = {
 };
 
 static const GtkActionEntry action_entries_file[] = {
-  {"Open",        GTK_STOCK_OPEN,         N_("_Open"),               "<control>O",            NULL,
+  {"Open",        GTK_STOCK_OPEN,    N_("_Open"),          "<control>O",    NULL,
    G_CALLBACK (cheese_window_cmd_open)},
-  {"SaveAs",      GTK_STOCK_SAVE_AS,      N_("Save _As..."),         "<control>S",            NULL,
+  {"SaveAs",      GTK_STOCK_SAVE_AS, N_("Save _As..."),    "<control>S",    NULL,
    G_CALLBACK (cheese_window_cmd_save_as)},
-  {"MoveToTrash", "user-trash",           N_("Move to _Trash"),      "Delete",                NULL,
+  {"MoveToTrash", "user-trash",      N_("Move to _Trash"), "Delete",        NULL,
    G_CALLBACK (cheese_window_move_media_to_trash)},
-  {"Delete",      NULL,                   N_("Delete"),              "<shift>Delete",         NULL,
+  {"Delete",      NULL,              N_("Delete"),         "<shift>Delete", NULL,
    G_CALLBACK (cheese_window_delete_media)},
 };
 
@@ -1560,6 +1575,7 @@ cheese_window_create_window (CheeseWindow *cheese_window)
   cheese_window->throbber_frame              = GTK_WIDGET (gtk_builder_get_object (builder, "throbber_frame"));
   cheese_window->countdown_frame             = GTK_WIDGET (gtk_builder_get_object (builder, "countdown_frame"));
   cheese_window->effect_frame                = GTK_WIDGET (gtk_builder_get_object (builder, "effect_frame"));
+  cheese_window->effect_alignment            = GTK_WIDGET (gtk_builder_get_object (builder, "effect_alignment"));
   cheese_window->message_area_frame          = GTK_WIDGET (gtk_builder_get_object (builder, "message_area_frame"));
   cheese_window->fullscreen_popup            = GTK_WIDGET (gtk_builder_get_object (builder, "fullscreen_popup"));
   cheese_window->fullscreen_bar              = GTK_WIDGET (gtk_builder_get_object (builder, "fullscreen_notebook_bar"));
